@@ -77,6 +77,10 @@ class ezfuc(object):
             return DefaultMunch.fromJSON(res, default)
         if isinstance(res, dict):
             return DefaultMunch.fromDict(res, default)
+        if isinstance(res, bytes):
+            res = res.decode("utf-8")
+            return DefaultMunch.fromDict(res, default)
+
 
     @staticmethod
     def object_to_dict(res, ex="dict"):
@@ -305,7 +309,7 @@ class ezfuc(object):
     def UUID(*arg):
         import uuid
         """
-        根据传过来的字符串进行"+"拼接后，进行uuid3加密
+        根据传过来的字符串进行拼接后，进行uuid3加密
         :param args:
         :return:
         """
@@ -314,7 +318,7 @@ class ezfuc(object):
         return str(uuid_str)
 
     @staticmethod
-    def color_print(*arg, color="yellow"):
+    def color_print(*arg, color="yellow", end="\n"):
         color_code = 33
         if color.lower() == "red":
             color_code = 31
@@ -326,7 +330,7 @@ class ezfuc(object):
             color_code = 35
 
         st = ' '.join(list(map(lambda x: str(x), arg)))
-        print(f'\033[1;{color_code}m{st}\033[0m')
+        print(f'\033[1;{color_code}m{st}\033[0m', end=end)
 
     @staticmethod
     def save_excel(resList, excel_name, title=None, path=""):
@@ -353,7 +357,6 @@ class ezfuc(object):
             resList = [list(i.values()) for i in resList]
         if title:
             resList.insert(0, title)
-        print(resList)
         for line in tqdm(resList, ascii=True, desc=excel_name):
             r = 00
             for i in line:
@@ -494,6 +497,15 @@ def getIP():
         getIP()
 
 
+import base64
+
+# 代理隧道验证信息
+proxyUser = "2120061500000940938"
+proxyPass = "fBGcLkyNK6He1FBn"
+
+# for Python3
+proxyAuth = "Basic " + base64.urlsafe_b64encode(bytes((proxyUser + ":" + proxyPass), "ascii")).decode("utf8")
+
 
 def ezproxy(req):
     res = getIP()
@@ -501,6 +513,7 @@ def ezproxy(req):
         return req
     try:
         req.meta["proxy"] = res["proxy"]
+        req.headers["Proxy-Authorization"] = proxyAuth
         return req
     except:
         return req
\ No newline at end of file
